==> igniteui-react-inputs-18.6.1.tgz: package/esm2015/lib/NativeUIXInputsFactory.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { INativeUIElementFactory_$type } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { XInputGroup } from "./XInputGroup";
import { XInput } from "./XInput";
import { XInputBridge } from "./XInputBridge";
import { NativeUIInput } from "igniteui-react-core";
import { XButton } from "./XButton";
import { XButtonBridge } from "./XButtonBridge";
import { NativeUIButton } from "igniteui-react-core";
import { XCheckbox } from "./XCheckbox";
import { XCheckboxBridge } from "./XCheckboxBridge";
import { NativeUICheckbox } from "igniteui-react-core";
import { XIcon } from "./XIcon";
import { XIconBridge } from "./XIconBridge";
import { NativeUIIcon } from "igniteui-react-core";
import { Popup } from "igniteui-react-core";
import { XPopupBridge } from "./XPopupBridge";
import { NativeUIPopup } from "igniteui-react-core";
/**
 * @hidden
 */
export let NativeUIXInputsFactory = /*@__PURE__*/ (() => {
    class NativeUIXInputsFactory extends Base {
        constructor() {
            super(...arguments);
            this.c = 2;
        }
        static get b() {
            if (NativeUIXInputsFactory.a == null) {
                NativeUIXInputsFactory.a = new NativeUIXInputsFactory();
            }
            return NativeUIXInputsFactory.a;
        }
        static j() {
            NativeUIComponent.ap(NativeUIXInputsFactory.b);
        }
        get flavor() {
            return this.c;
        }
        createComponent(a, b, c) {
            switch (b) {
                case 1:
                    this.d(a, c);
                    break;
                case 6:
                    this.e(a, c);
                    break;
                case 10:
                    this.g(a, c);
                    break;
                case 2:
                    this.h(a, c);
                    break;
                case 11:
                    this.f(a, c);
                    break;
                case 12:
                    this.i(a, c);
                    break;
            }
        }
        createComponentSync(a, b, c) {
            this.createComponent(a, b, c);
        }
        supportsComponent(a) {
            switch (a) {
                case 1: return true;
                case 6: return true;
                case 10: return true;
                case 2: return true;
                case 11: return true;
                case 12: return true;
            }
            return false;
        }
        h(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XInputGroup();
            f.provideContainer(e);
            let g = e.getExternal(f, e.rootWrapper, null);
            let h = c.createElement("div");
            h.setRawStyleProperty("width", "100%");
            let i = c.getSubRenderer(h);
            let j = new XInput();
            j.provideContainer(i);
            let k = e.getExternal(j, i.rootWrapper, null);
            f.appendContentChild(h);
            f.inputs.add(j);
            let l = new XInputBridge(f);
            let m = new NativeUIInput();
            m.al = d;
            m.d = l;
            b(m);
        }
        d(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XButton();
            f.provideContainer(e);
            f.ff = "none";
            let g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
            let h = new XButtonBridge(f);
            let i = new NativeUIButton();
            i.al = d;
            i.d = h;
            b(i);
        }
        e(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XCheckbox();
            f.provideContainer(e);
            let g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
            let h = new XCheckboxBridge(f);
            let i = new NativeUICheckbox();
            i.al = d;
            i.d = h;
            b(i);
        }
        g(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XIcon();
            f.provideContainer(e);
            let g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
            let h = new XIconBridge(f);
            let i = new NativeUIIcon();
            i.al = d;
            i.d = h;
            let j = c.createElement("div");
            let k = c.getSubRenderer(j);
            let l = new XButton();
            l.provideContainer(k);
            l.e = 4;
            l.ff = "none";
            let m = k.getExternal(l, k.rootWrapper, k.getExternal(l, null, null));
            let n = new XButtonBridge(l);
            let o = new NativeUIButton();
            o.al = j;
            o.d = n;
            o.bk = i;
            b(o);
        }
        f(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XIcon();
            f.provideContainer(e);
            let g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
            let h = new XIconBridge(f);
            let i = new NativeUIIcon();
            i.al = d;
            i.d = h;
            b(i);
        }
        i(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new Popup();
            f.provideRenderer(e);
            let g = new XPopupBridge(f);
            let h = new NativeUIPopup();
            h.al = d;
            h.d = g;
            b(h);
        }
    }
    NativeUIXInputsFactory.$t = /*@__PURE__*/ markType(NativeUIXInputsFactory, 'NativeUIXInputsFactory', Base.$, [INativeUIElementFactory_$type]);
    NativeUIXInputsFactory.a = null;
    return NativeUIXInputsFactory;
})();

==> igniteui-react-inputs-18.7.3.tgz: package/esm2015/lib/NativeUIXInputsFactory.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, markType } from "igniteui-react-core";
import { INativeUIElementFactory_$type } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { XInputGroup } from "./XInputGroup";
import { XInput } from "./XInput";
import { XInputBridge } from "./XInputBridge";
import { NativeUIInput } from "igniteui-react-core";
import { XButton } from "./XButton";
import { XButtonBridge } from "./XButtonBridge";
import { NativeUIButton } from "igniteui-react-core";
import { XCheckbox } from "./XCheckbox";
import { XCheckboxBridge } from "./XCheckboxBridge";
import { NativeUICheckbox } from "igniteui-react-core";
import { XIcon } from "./XIcon";
import { XIconBridge } from "./XIconBridge";
import { NativeUIIcon } from "igniteui-react-core";
import { Popup } from "igniteui-react-core";
import { XPopupBridge } from "./XPopupBridge";
import { NativeUIPopup } from "igniteui-react-core";
/**
 * @hidden
 */
export let NativeUIXInputsFactory = /*@__PURE__*/ (() => {
    class NativeUIXInputsFactory extends Base {
        constructor() {
            super(...arguments);
            this.c = 2;
        }
        static get b() {
            if (NativeUIXInputsFactory.a == null) {
                NativeUIXInputsFactory.a = new NativeUIXInputsFactory();
            }
            return NativeUIXInputsFactory.a;
        }
        static j() {
            NativeUIComponent.ar(NativeUIXInputsFactory.b);
        }
        get flavor() {
            return this.c;
        }
        createComponent(a, b, c) {
            switch (b) {
                case 1:
                    this.d(a, c);
                    break;
                case 6:
                    this.e(a, c);
                    break;
                case 10:
                    this.g(a, c);
                    break;
                case 2:
                    this.h(a, c);
                    break;
                case 11:
                    this.f(a, c);
                    break;
                case 12:
                    this.i(a, c);
                    break;
            }
        }
        createComponentSync(a, b, c) {
            this.createComponent(a, b, c);
        }
        supportsComponent(a) {
            switch (a) {
                case 1: return true;
                case 6: return true;
                case 10: return true;
                case 2: return true;
                case 11: return true;
                case 12: return true;
            }
            return false;
        }
        h(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XInputGroup();
            f.provideContainer(e);
            let g = e.getExternal(f, e.rootWrapper, null);
            let h = c.createElement("div");
            h.setRawStyleProperty("width", "100%");
            let i = c.getSubRenderer(h);
            let j = new XInput();
            j.provideContainer(i);
            let k = e.getExternal(j, i.rootWrapper, null);
            f.appendContentChild(h);
            f.inputs.add(j);
            let l = new XInputBridge(f);
            let m = new NativeUIInput();
            m.an = d;
            m.d = l;
            b(m);
        }
        d(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XButton();
            f.provideContainer(e);
            f.ff = "none";
            let g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
            let h = new XButtonBridge(f);
            let i = new NativeUIButton();
            i.an = d;
            i.d = h;
            b(i);
        }
        e(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XCheckbox();
            f.provideContainer(e);
            let g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
            let h = new XCheckboxBridge(f);
            let i = new NativeUICheckbox();
            i.an = d;
            i.d = h;
            b(i);
        }
        g(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XIcon();
            f.provideContainer(e);
            let g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
            let h = new XIconBridge(f);
            let i = new NativeUIIcon();
            i.an = d;
            i.d = h;
            let j = c.createElement("div");
            let k = c.getSubRenderer(j);
            let l = new XButton();
            l.provideContainer(k);
            l.e = 4;
            l.ff = "none";
            let m = k.getExternal(l, k.rootWrapper, k.getExternal(l, null, null));
            let n = new XButtonBridge(l);
            let o = new NativeUIButton();
            o.an = j;
            o.d = n;
            o.bm = i;
            b(o);
        }
        f(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new XIcon();
            f.provideContainer(e);
            let g = e.getExternal(f, e.rootWrapper, e.getExternal(f, null, null));
            let h = new XIconBridge(f);
            let i = new NativeUIIcon();
            i.an = d;
            i.d = h;
            b(i);
        }
        i(a, b) {
            let c = a;
            let d = c.createElement("div");
            let e = c.getSubRenderer(d);
            let f = new Popup();
            f.provideRenderer(e);
            let g = new XPopupBridge(f);
            let h = new NativeUIPopup();
            h.an = d;
            h.d = g;
            b(h);
        }
    }
    NativeUIXInputsFactory.$t = /*@__PURE__*/ markType(NativeUIXInputsFactory, 'NativeUIXInputsFactory', Base.$, [INativeUIElementFactory_$type]);
    NativeUIXInputsFactory.a = null;
    return NativeUIXInputsFactory;
})();
